<?php
/**
* Return text based on language and domain name using the php_gettext package 
* Pure PHP implementation that works on Win2k8 64 bits
*
* PHP versions 5
* 
* @category  PHP
* @package   GeoPrisma  
* @author    Stephane Guillemette
* @author    Pascal Martin, Etienne Dube
* @copyright 2011, Boreal - Information Strategies
* @license   http://www.geoprisma.org/license BSD License
* @link      http://www.geoprisma.org
*/

/**
* Return text based on language and domain name using the php_gettext package 
*  
* @category   PHP 
* @package    GeoPrisma
* @subpackage UI
* @author     Stephane Guillemette
* @author     Pascal Martin
* @author     Etienne Dube
* @author     Charles Villemure
*/      

require_once('gettext.inc');

class org_geoprisma_locale_PhpGetTextLocale extends org_geoprisma_locale_Locale
{
    private static $s_objInstance = null;
 
    /**
    * Construit un instance de org_geoprisma_locale_PhpGetTextLocale
    * 
    * @return org_geoprisma_locale_GetTextLocale
    */   
    private function __construct()
    {
        // Constructeur privé pour forcer l'utilisation de getInstance (Singleton DP)      
        $this->setLanguage($this->getDefaultLanguage());    
    }
    
    /**
    * Retourne un instance de org_geoprisma_locale_PhpGetTextLocale
    * Singleton DP
    * 
    * @return org_geoprisma_locale_PhpGetTextLocale
    */
    public static function getInstance()
    {
        if (is_null(self::$s_objInstance))
        {
            self::$s_objInstance = new org_geoprisma_locale_PhpGetTextLocale();
        }
        return self::$s_objInstance;
    }
    
    /**
    * Set the current use langage for traduction (e.g. en_US , fr_CA)
    * 
    * @param string $pstrLanguage Language
    * 
    * @return void
    */
    public function setLanguage($pstrLanguage)
    {		
		parent::setLanguage($pstrLanguage);
        putenv("LANGUAGE=$pstrLanguage");
		T_setlocale(LC_ALL, $pstrLanguage.".UTF8");
    }
      
    /**
    * Return text based on domainName for right language
    * 
    * @param string $pstrMsg        Message Key
    * @param string $pstrDomainName Name of the 
    *
    * @return string 
    */  
    public function getTranslation($pstrMsg, $pstrDomainName)
    {
        T_bindtextdomain($pstrDomainName, org_geoprisma_SettingImpl::getLocaleDir());
        T_bind_textdomain_codeset($pstrDomainName, "UTF-8");
        T_textdomain($pstrDomainName);
        return T_($pstrMsg);
    } 
}
?>
